# Governance

This project is governed by our [Code of Conduct](https://github.com/davidbrownell/uvRepoTemplate/blob/main/CODE_OF_CONDUCT.md) and [Contribution Guidelines](https://github.com/davidbrownell/uvRepoTemplate/blob/main/CONTRIBUTING.md).
